@@ -26,9 +26,17 @@ class ItemBuffer(BaseItemBuffer):
 
         :return:
         """
-        item_filter_pipeline = import_module(
-            settings.ITEM_FILTER_PIPELINE[settings.SPIDER_TYPE][settings.FILTERING_MODE])
-        cls.PIPELINE = item_filter_pipeline + import_module(settings.PIPELINE)
+        pipeline_list = [
+            import_module(settings.ITEM_FILTER_PIPELINE[settings.SPIDER_TYPE][settings.FILTERING_MODE]),
+            import_module(settings.PIPELINE)
+        ]
+
+        cls.PIPELINE.extend(pipeline_list)
+
+        if settings.ITEM_FAILED_SAVE:
+            cls.PIPELINE.append(
+                import_module('palp.pipeline.pipeline_recycle.ItemRecyclePipeline')
+            )
 
     def run(self) -> None:
         """
