@@ -1,4 +1,4 @@
-from palp.pipeline.pipeline_item_filter import ItemBloomFilterPipeline, ItemRedisBloomFilterPipeline, \
+from palp.pipeline.pipeline_filter import ItemBloomFilterPipeline, ItemRedisBloomFilterPipeline, \
     ItemRedisFilterPipeline, ItemMemoryFilterPipeline
 
 from palp.pipeline.pipeline_base import Pipeline
